@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
 
 #include <QObject>
 #include <KContacts/ResourceLocatorUrl>
-namespace KAddressBookGrantlee
-{
+namespace KAddressBookGrantlee {
 class ContactGrantleeWebSite : public QObject
 {
     Q_OBJECT
