@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -46,12 +46,12 @@ public:
 private:
     void readSettings();
     void writeSettings();
-    QCheckBox *mPrivateBox;
-    QCheckBox *mBusinessBox;
-    QCheckBox *mOtherBox;
-    QCheckBox *mEncryptionKeys;
-    QCheckBox *mPictureBox;
-    QCheckBox *mDisplayNameBox;
+    QCheckBox *mPrivateBox = nullptr;
+    QCheckBox *mBusinessBox = nullptr;
+    QCheckBox *mOtherBox = nullptr;
+    QCheckBox *mEncryptionKeys = nullptr;
+    QCheckBox *mPictureBox = nullptr;
+    QCheckBox *mDisplayNameBox = nullptr;
 };
 }
 #endif // KADDRESSBOOKEXPORTSELECTIONWIDGET_H
